Learn R Programming

NUETON (version 0.2.0)

NRE: Calculate Fertilizer N Recovery Efficiency (NRE)

Description

The percentage of fertilizer N that is taken up by the plant. Formula: NRE = ((PlantNf - PlantN0) / FertN) * 100

Usage

NRE(PlantNf, PlantN0, FertN)

Value

A numeric vector of NRE percentages.

Arguments

PlantNf

A numeric vector of plant N in fertilized conditions.

PlantN0

A numeric vector of plant N in control conditions.

FertN

A numeric value or vector for fertilizer N input.

Examples

Run this code
PlantNf <- c(3.5, 4.0, 4.2)
PlantN0 <- c(2.0, 2.0, 2.0)
FertN <- 50
NRE(PlantNf, PlantN0, FertN)

Run the code above in your browser using DataLab