Learn R Programming

NUETON (version 0.2.0)

NUEcrop: Calculate NUE Crop

Description

The fraction of fertilizer N that is utilized and allocated to yield N. Formula: NUEcrop = YieldN / FertN

Usage

NUEcrop(YieldN, FertN)

Value

A numeric vector of NUEcrop values.

Arguments

YieldN

A numeric vector of the N removed as yield.

FertN

A numeric value or vector for fertilizer N input.

Examples

Run this code
YieldN <- c(80, 90, 100)
FertN <- 50
NUEcrop(YieldN, FertN)

Run the code above in your browser using DataLab