Learn R Programming

NUETON (version 0.2.0)

NUEsoil: Calculate NUE Soil

Description

The biomass production per unit of available N. Formula: NUEsoil = PlantBM / (FertN + SoilN)

Usage

NUEsoil(PlantBM, SoilN, FertN)

Value

A numeric vector of NUEsoil values.

Arguments

PlantBM

A numeric vector of plant biomass.

SoilN

A numeric value or vector for soil N content.

FertN

A numeric value or vector for fertilizer N input.

Examples

Run this code
PlantBM <- c(100, 120, 130)
SoilN <- c(20, 20, 20)
FertN <- 50
NUEsoil(PlantBM, SoilN, FertN)

Run the code above in your browser using DataLab