Learn R Programming

NUETON (version 0.2.0)

NUpE: Calculate N Uptake Efficiency (NUpE)

Description

The percentage of available soil N that is utilized by the plant. Formula: NUpE = (PlantN / (FertN + SoilN)) * 100

Usage

NUpE(PlantN, SoilN, FertN)

Value

A numeric vector of NUpE percentages.

Arguments

PlantN

A numeric vector of values for plant N content.

SoilN

A numeric value or vector for soil N content.

FertN

A numeric value or vector for fertilizer N input.

Examples

Run this code
PlantN <- c(3.0, 3.5, 3.8)
SoilN <- c(20, 20, 20)
FertN <- 50
NUpE(PlantN, SoilN, FertN)

Run the code above in your browser using DataLab