Learn R Programming

NUETON (version 0.2.0)

PNB: Calculate Partial N Balance (PNB)

Description

The expression of plant N content per unit of fertilizer N applied. Formula: PNB = PlantNf / FertN

Usage

PNB(PlantNf, FertN)

Value

A numeric vector of PNB values.

Arguments

PlantNf

A numeric vector of Plant N content in fertilized conditions.

FertN

A numeric value or vector for fertilizer N input.

Examples

Run this code
PlantNf <- c(3.5, 4.0, 4.2)
FertN <- 50
PNB(PlantNf, FertN)

Run the code above in your browser using DataLab