powered by
The percentage of fertilizer N that is taken up by the plant. Formula: NRE = ((PlantNf - PlantN0) / FertN) * 100
NRE(PlantNf, PlantN0, FertN)
A numeric vector of NRE percentages.
A numeric vector of plant N in fertilized conditions.
A numeric vector of plant N in control conditions.
A numeric value or vector for fertilizer N input.
PlantNf <- c(3.5, 4.0, 4.2) PlantN0 <- c(2.0, 2.0, 2.0) FertN <- 50 NRE(PlantNf, PlantN0, FertN)
Run the code above in your browser using DataLab