powered by
The fraction of fertilizer N that is utilized and allocated to yield N. Formula: NUEcrop = YieldN / FertN
NUEcrop(YieldN, FertN)
A numeric vector of NUEcrop values.
A numeric vector of the N removed as yield.
A numeric value or vector for fertilizer N input.
YieldN <- c(80, 90, 100) FertN <- 50 NUEcrop(YieldN, FertN)
Run the code above in your browser using DataLab