powered by
The biomass production per unit of available N. Formula: NUEsoil = PlantBM / (FertN + SoilN)
NUEsoil(PlantBM, SoilN, FertN)
A numeric vector of NUEsoil values.
A numeric vector of plant biomass.
A numeric value or vector for soil N content.
A numeric value or vector for fertilizer N input.
PlantBM <- c(100, 120, 130) SoilN <- c(20, 20, 20) FertN <- 50 NUEsoil(PlantBM, SoilN, FertN)
Run the code above in your browser using DataLab