powered by
The percentage of available soil N that is utilized by the plant. Formula: NUpE = (PlantN / (FertN + SoilN)) * 100
NUpE(PlantN, SoilN, FertN)
A numeric vector of NUpE percentages.
A numeric vector of values for plant N content.
A numeric value or vector for soil N content.
A numeric value or vector for fertilizer N input.
PlantN <- c(3.0, 3.5, 3.8) SoilN <- c(20, 20, 20) FertN <- 50 NUpE(PlantN, SoilN, FertN)
Run the code above in your browser using DataLab