powered by
The expression of plant N content per unit of fertilizer N applied. Formula: PNB = PlantNf / FertN
PNB(PlantNf, FertN)
A numeric vector of PNB values.
A numeric vector of Plant N content in fertilized conditions.
A numeric value or vector for fertilizer N input.
PlantNf <- c(3.5, 4.0, 4.2) FertN <- 50 PNB(PlantNf, FertN)
Run the code above in your browser using DataLab